@@ -3,8 +3,13 @@ pub const SDK_STRING_MAX_LEN: usize = 128;
 #[allow(non_camel_case_types)]
 #[repr(C)]
 pub enum HandlerResult {
+    /// Proceed to the next command
     CONTINUE = 0,
-    TERMINATE = 1,
+    /// Pause the script and continue on the next game loop iteration
+    BREAK = 1,
+    /// End the script gracefully
+    TERMINATE = 2,
+    /// End the script and throw an error
     ERR = -1,
 }
 
@@ -64,27 +69,27 @@ extern "C" {
     fn RegisterCommand(name: *const c_char, cb: CustomCommand, permission: *const c_char);
     /// since v1
     ///
-    /// Reads an integer argument (32 or 64 bit depending on target platform)
+    /// Reads an integer argument (either 32 or 64 bit depending on the target platform) from the script input
     fn GetIntParam(ctx: Context) -> isize;
     /// since v1
     ///
-    /// Reads a floating-point argument
+    /// Reads a floating-point argument from the script input
     fn GetFloatParam(ctx: Context) -> f32;
     /// since v1
     ///
-    /// Reads a string argument
-    fn GetStringParam(ctx: Context, dest: *mut c_char, maxlen: u8);
+    /// Copies atmost {maxlen} bytes of a UTF-8 encoded character sequence in the script input to {dest}
+	fn GetStringParam(ctx: Context, dest: *mut c_char, maxlen: u8);
     /// since v1
     ///
-    /// Writes the integer value (32 or 64 bit depending on target platform)
+    /// Writes the integer {value} (either 32 or 64 bit depending on the target platform) to the script output
     fn SetIntParam(ctx: Context, value: isize);
     /// since v1
     ///
-    /// Writes the floating-point value
+    /// Writes the floating-point {value} to the script output
     fn SetFloatParam(ctx: Context, value: f32);
     /// since v1
     ///
-    /// Writes the string value
+    /// Copies a null-terminated UTF-8 encoded character sequence from {src} to the script output
     fn SetStringParam(ctx: Context, src: *const c_char);
     /// since v1
     ///
